@@ -11,6 +11,8 @@ from ..services.integration import IntegrationService
 from ..services.task import TaskService
 from ..services.user import UserService
 from ..services.workflow import WorkflowService
+from ..services.files import FileOperationService
+from ..services.webhook import WebhookService
 
 
 class CodeMieClient:
@@ -51,6 +53,7 @@ class CodeMieClient:
 
         self._token: Optional[str] = None
         self._api_domain = codemie_api_domain.rstrip("/")
+        self._is_localhost = self._is_localhost_domain(self._api_domain)
         self._verify_ssl = verify_ssl
         if not verify_ssl:
             import requests
@@ -58,8 +61,8 @@ class CodeMieClient:
 
             requests.packages.urllib3.disable_warnings(InsecureRequestWarning)
 
-        # Initialize token first
-        self._token = self.auth.get_token()
+        # Initialize token
+        self._token = "" if self._is_localhost else self.auth.get_token()
 
         # Initialize services with verify_ssl parameter and token
         self.assistants = AssistantService(
@@ -80,17 +83,33 @@ class CodeMieClient:
         self.conversations = ConversationService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
         )
+        self.files = FileOperationService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
+        self.webhook = WebhookService(
+            self._api_domain, self._token, verify_ssl=self._verify_ssl
+        )
 
     @property
     def token(self) -> str:
         """Get current token or fetch new one if not available."""
-        if not self._token:
-            self._token = self.auth.get_token()
+        self._token = "" if self._is_localhost else self.auth.get_token()
         return self._token
 
+    @staticmethod
+    def _is_localhost_domain(domain: str) -> bool:
+        """Check if the domain is a localhost variant."""
+        domain_lower = domain.lower()
+        localhost_patterns = [
+            "localhost",
+            "127.0.0.1",
+            "0.0.0.0",
+        ]
+        return any(pattern in domain_lower for pattern in localhost_patterns)
+
     def refresh_token(self) -> str:
         """Force token refresh."""
-        self._token = self.auth.get_token()
+        self._token = "" if self._is_localhost else self.auth.get_token()
         # Update token in services
         self.assistants = AssistantService(
             self._api_domain, self._token, verify_ssl=self._verify_ssl
